function []=cubePlot(particleLabel,dim_nc,dim_nc_tot,pos,theta,M,Mu)

M=M*dim_nc; %makes the magnetic moment longer for visualisation

A=@(x,y,z) [cos(y)*cos(z),-cos(y)*sin(z),-sin(y);...
cos(x)*sin(z)-sin(x)*sin(y)*cos(z),sin(x)*sin(y)*sin(z)+cos(x)*cos(z),-sin(x)*cos(y);...
cos(x)*sin(y)*cos(z)+sin(x)*sin(z),sin(x)*cos(z)-cos(x)*sin(y)*sin(z),cos(x)*cos(y)];

%making an arrowhead (in spherical coordinates)
arrow=[sin(7*pi/8)*cos(pi/4),sin(7*pi/8)*cos(3*pi/4),sin(7*pi/8)*cos(5*pi/4),sin(7*pi/8)*cos(7*pi/4),0;...
    sin(7*pi/8)*sin(pi/4),sin(7*pi/8)*sin(3*pi/4),sin(7*pi/8)*sin(5*pi/4),sin(7*pi/8)*sin(7*pi/4),0;...
    cos(7*pi/8),cos(7*pi/8),cos(7*pi/8),cos(7*pi/8),0]*dim_nc/3;

thetay=asin(-Mu(particleLabel,1));
thetax1=acos(Mu(particleLabel,3)/cos(thetay));
thetax2=asin(-Mu(particleLabel,2)/cos(thetay));

     if thetax2<0
         thetax=2*pi-thetax1;
     else
         thetax=thetax1;
     end

arrow=A(thetax,thetay,0)*arrow;
arrow=(A(theta(particleLabel,1),theta(particleLabel,2),theta(particleLabel,3))*arrow)';

arrow(:,1)=arrow(:,1)+M(particleLabel,1)/2+pos(particleLabel,1);
arrow(:,2)=arrow(:,2)+M(particleLabel,2)/2+pos(particleLabel,2);
arrow(:,3)=arrow(:,3)+M(particleLabel,3)/2+pos(particleLabel,3);


%cubes moved to origo (no rotations)
vertices1 = [-1 -1 -1; -1 1 -1; 1 1 -1; 1 -1 -1; -1 -1 1; -1 1 1; 1 1 1; 1 -1 1]*dim_nc/2;
vertices2 = [-1 -1 -1; -1 1 -1; 1 1 -1; 1 -1 -1; -1 -1 1; -1 1 1; 1 1 1; 1 -1 1]*dim_nc_tot/2;

%performing rotaion operation of vertex coordinates
vertices=[vertices1;vertices2]';
vertices=(A(theta(particleLabel,1),theta(particleLabel,2),theta(particleLabel,3))*vertices)';

%moving cubes back to designated positions
vertices(:,1)=vertices(:,1)+pos(particleLabel,1);
vertices(:,2)=vertices(:,2)+pos(particleLabel,2);
vertices(:,3)=vertices(:,3)+pos(particleLabel,3);


vertices1=vertices(1:8,:);
vertices2=vertices(9:end,:);
faces = [1 2 3 4; 2 6 7 3; 4 3 7 8; 1 5 8 4; 1 2 6 5; 5 6 7 8];


%plotting the cubes
plot3(pos(particleLabel,1),pos(particleLabel,2),pos(particleLabel,3));

hold on

patch('Vertices', vertices1, 'Faces', faces, 'FaceColor', 'k','FaceAlpha',0.7);
patch('Vertices', vertices2, 'Faces', faces, 'FaceColor', 'y','EdgeColor','none','FaceAlpha',0.25);

plot3([pos(particleLabel,1)-M(particleLabel,1)/2,pos(particleLabel,1)+M(particleLabel,1)/2],[pos(particleLabel,2)-M(particleLabel,2)/2,pos(particleLabel,2)+M(particleLabel,2)/2],[pos(particleLabel,3)-M(particleLabel,3)/2,pos(particleLabel,3)+M(particleLabel,3)/2],'r','LineWidth',2.5)
patch('Vertices', arrow, 'Faces', [1 2 3 4;1 2 5 1;2 3 5 2;3 4 5 3;1 4 5 1], 'FaceColor', 'r','EdgeColor','none');



end